/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-08 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

/**
 * Handles alignment of a given paragraph
 * @author alb
 */
public class Alignment
{
    /** the only allowed alignment values */
    public enum type { LEFT, RIGHT, CENTER, JUSTIFIED }

    /** the present alignment */
    private type present;

    /** line number where alignment was set */
    private int lineNumber;

    /**
     * sets default alignment to left
     */
    public Alignment()
    {
        present = PlatyConst.DEFAULT_ALIGNMENT;
        lineNumber = 0;
    }

    public type getPresent()
    {
        return present;
    }

    public void setPresent( final type present )
    {
        this.present = present;
        lineNumber = GID.getInstance().getCurrLine().getLineNumber();
    }

    public int getLineNumber()
    {
        return lineNumber;
    }

    /**
     * Creates a string containing the line # and the value of the bottom margin when last set
     * @return formatted string suitable for use in dump()
     */
    public String dump()
    {
        final Literals lits = Literals.getInstance();

        final StringBuffer sb = new StringBuffer();
        sb.append( lits.getLit( "ALIGNMENT" ))
          .append( " (" )
          .append( lits.getLit( "LINE" ))
          .append( " " )
          .append( lineNumber )
          .append( ") " );

        switch( present ) {
            case CENTER:    sb.append( lits.getLit( "CENTER" ));    break;
            case JUSTIFIED: sb.append( lits.getLit( "JUSTIFIED" )); break;
            case LEFT:      sb.append( lits.getLit( "LEFT" ));      break;
            case RIGHT:     sb.append( lits.getLit( "RIGHT" ));     break;
        }
        return( sb.toString() );
    }
}
