/*-
 *  (c) Copyright 2006-7 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 *
 *  For more information about platter, go to http://platypus.pz.org
 */
package platypus;

/**
 * Class for the individual commands that are placed in the CommandList and later
 * executed
 *
 * @author alb
 */
public class Command
{

    private String abbrev;
    private String name;
    private String root;
    private TokTyp type;

    protected GDD gdd;
    protected GID gid;
    protected Literals lits;

    public Command()
    {
        gdd = GDD.getInstance();
        gid = GID.getInstance();
        lits = Literals.getInstance();
    }

    public Command( final String abbreviation, final String commandName, final TokTyp commandType )
    {
        this();

        abbrev = abbreviation;
        name = commandName;
        root = null;
        type = commandType;
    }

    /**
     * this method processes the actual command. It should be overridden. Defaults to
     * an error that the command is not supported.
     * 
     * @return Status.OK if all went well, otherwise error status
     */
    public int process( String actualCommand )
    {
//        gdd.getLogger().info( //TODO: route to logger
        System.out.println(
                "(" +
                lits.getLit( "LINE_NUM_SIGN" ) + " " + gid.getCurrLine().getLineNumber() + ") " +
                name +  " ( " + actualCommand +" ) " +
                lits.getLit( "NOT_SUPPORTED" ) + " in " +
                Platypus.platyStrings.getString( "$_outputFormat" ) + ". " +
                lits.getLit( "IGNORED") );

        return( Status.UNSUPPORTED_COMMAND );
    }

    public String getAbbrev() {
        return abbrev;
    }

    public void setAbbrev( final String abbrev ) {
        this.abbrev = abbrev;
    }

    public String getName() {
        return name;
    }

    public void setName( final String name ) {
        this.name = name;
    }

    public String getRoot() {
        return root;
    }

    public void setRoot( final String root ) {
        this.root = root;
    }
    
    public TokTyp getType() {
        return type;
    }

    public void setType( final TokTyp type ) {
        this.type = type;
    }
}
