/*
 *   global infile data, including all state information for the input file
 *
 *  (c) Copyright 2006-7 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

/**
 * GID is the Global Input-file Data class. It contains  properties relating to
 * the input file.
 * Implemented using the Singleton pattern because it is a one-time global item.
 * @author alb
 */
public class GID   // Global Input Data 
{
    private Infile infile = null;                   // class representing current input file
    private ReadLine currLine = null;               // the line we're currently processing.
    private Tokens tokens;                          // the tokens in the current line
    private Tokens currentLineTokens;
    private int currentTokenNumber;                 // which token is being processed (0-based)

    private GID()
    {
        currLine = new ReadLine();
    }
    /** fields and functions needed for instantiation of singleton */
    private static final GID thisInstance = new GID();    // we instantiate eagerly, not lazily

    /**
     * The function used by singleton pattern to return handle to this class
     * @return handle to this instance of GID class
     */
    public static GID getInstance()
    {
        return thisInstance;
    }

    /**
     * mostly used in testing to put GID back into a known state.
     */
    public void initialize()
    {
        infile = null;
        currLine.setLineNumber( 0 );
        currLine.setContent( "" );
        tokens = null;
        currentTokenNumber = 0;
    }

    /**
     * Returns the current line
     * @return currLine the current line
     */
    public ReadLine getCurrLine()
    {
        return( currLine );
    }

    public int getCurrentTokenNumber() {
        return currentTokenNumber;
    }

    public void setCurrentTokenNumber( final int currentTokenNumber ) {
        this.currentTokenNumber = currentTokenNumber;
    }

    public Tokens getCurrentLineTokens() {
        return currentLineTokens;
    }

    public void setCurrentLineTokens( final Tokens newCurrentLineTokens ) {
        currentLineTokens = newCurrentLineTokens;
    }

    public Infile getInfile()
    {
        return( infile );
    }

    public void setInfile( final Infile newInfile )
    {
        infile = newInfile;
    }

    public Tokens getTokens()
    {
        return tokens;
    }

    public void setTokens( final Tokens newTokens )
    {
        tokens = newTokens;
    }

    //=== For testing only (FTO) ======//
    /**
     * This function is FTO because and not used in production code because GID only has the one
     * currLine. The contents of that currLine is changed by setters in ReadLine, rather than by
     * being reset here. This is probably not good OOD and, after careful thought, should probably
     * be changed.
     *
     * @param newRL the new ReadLine to replace currLine
     */

    public void FTOsetCurr( final ReadLine newRL )
    {
        currLine = newRL;
    }
}
