/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-08 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */
 //  TODO: add ability to switch to a different resource bundle.

package platypus;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * Handles getting literal strings from resource bundle. The default resource bundle, called
 * Platypus.properties, must be present or the program aborts. It is in US English. If another
 * language is used, please see documentation to access the appropriate resource bundle.
 *
 * @author alb
 */
public class Literals
{
    private static final Literals thisInstance =
            new Literals( "platypus/resources/Platypus" );  // instantiate eagerly, not lazily
    public  static Literals getInstance() { return thisInstance; }
    private ResourceBundle lits;

    /**
     * Open a resource bundle with the name: resourceName.properties
     * In the event the resource bundle cannot be found, the program
     * shuts down. Clearly, this is a fatal error.
     * *
     * @param resourceName  name of the resource bundle
     */
    private Literals( final String resourceName )
    {
        try
        {
            lits = ResourceBundle.getBundle( resourceName );
        }
        catch( MissingResourceException mre )
        {
            // this must write to System.err because it will occur before any logger
            // has been created.
            System.err.println( "Missing file: " + resourceName + ".properties, " +
                    "which is required. " +
                    "Copy it to the directory where platter is running and restart.\n" );
            System.exit( Status.FATAL_ERR );
        }
    }

    /**
     * Looks up a literal in the resource bundle. In the event of error,
     * it returns a string consisting of one blank. In this manner, the
     * program will continue to work if someone has diddled with the resource
     * file, but it will have one (or more) blank literals.
     *
     * @param key the name of the literal to be looked up
     * @return the literal String that was searched for
     */
    public String getLit( final String key )
    {
        String lit;

        if ( key == null ) {
            GDD.getInstance().getLogger().warning( " null not found in .properties file." );
            return( " " );
        }

        try
        {
            lit = lits.getString( key );
        }
        catch( MissingResourceException mre )
        {
            lit = " ";
            GDD.getInstance().getLogger().warning( key + " not found in .properties file." );
        }
        return( lit );
    }
}
