/*-
 * (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 *
 *  For more information about platypus, go to http://platypus.pz.org
 * //TODO: This class has a direct dependcy on PDF in the new page routine. Remove this.
 **/

package platypus;

/**
 * A different instantiation of Outfile is used for each type of generated file
 * @author alb
 */
abstract public class Outfile
{
    /** name of the output file */
    private String filename = "";

    /** the type of file: PDF, HTML, etc. */
    private GDD.FileType fileType;

    /** is the file open? so, true = open; false = not open */
    private boolean openStatus;

    /** some commands cannot occur after any text has been ouput. To monitor, we use this flag. */
    protected boolean textProcessedFlag = false;

    public Outfile()
    {
    }

    public GDD.FileType getFileType()
    {
        return fileType;
    }

    public void setFileType( final GDD.FileType newFileType )
    {
        fileType = newFileType;
    }

    public String getFilename()
    {
        return( filename );
    }

    public void setFilename( String newName )
    {
        filename = newName;
    }

    public void setOpenStatus( final boolean newStatus )
    {
        openStatus = newStatus;
    }

    public boolean isOpen()
    {
        return openStatus;
    }

    public boolean hasTextBeenProcessed()
    {
        return textProcessedFlag;
    }

    public void setTextProcessedFlag( final boolean newFlagValue )
    {
        textProcessedFlag = newFlagValue;
    }

    //=== methods implemented in subclasses

    public void addColumnsContentToDocument() {}
    public int  addParagraph() { return Status.OK; }
    public void close(){}
    public void doNewParagraph() {}
    public void emitText( String s ) {}
    public void emitRawText( String s ){}
    public boolean lowLevelPdfNewPage() { return false; }
    public int  newPage() { return( Status.OK ); }
}
