/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

import platypus.html.OutfileHtml;
import platypus.pdf.OutfilePdf;
import platypus.pdf.PageFooterPdf;

/**
 * Note: these classes/methods will eventually replaced by plug-ins for the various output file formats.
 * =============================================================================================
 * 
 * Object factory for classes that are specific to the output-file format. These
 * include: Outfile, Command, etc.
 *
 * @author alb
 */
public class OutputFormatObjectFactory
{
    /**
     * Creates a Command object for the passed-in output file type.
     * @param fileType the output file type (PDF, HTML, etc.)
     * @return  the Command object if all went well, otherwise null
     */
    public CommandProcessor CreateCommandProcessor( GDD.FileType fileType )
    {
        /*
         * Eventually the following will be replaced by code that loads
         * a plugin for the external file format.
         */
        if ( fileType != null ) {
            switch( fileType )
            {
                case IS_PDF:    return( new platypus.pdf.CommandProcess() );
                case IS_HTML:   return( new platypus.html.CommandProcess() );

                default:        return( null );
            }
        }
        else {
            return( null );
        }
    }

    /**
     * Creates an Outfile object for the passed-in output file type.
     * @param fileType the output file type (PDF, HTML, etc.)
     * @return  the Oufile object if all went well, otherwise null
     */
    public Outfile CreateOutfile( GDD.FileType fileType )
    {
        if ( fileType != null ) {
            switch( fileType )
            {
                case IS_PDF:    return( new OutfilePdf() );
                case IS_HTML:   return( new OutfileHtml() );

                default:     return( null );
            }
        }
        else {
            return( null );
        }
    }

    /**
     * Creates a Footer object for the passed-in output file type.
     * @param fileType the output file type (PDF, HTML, etc.)
     * @return  the footer object if all went well, otherwise null
     */
    public PageFooter CreateFooter( GDD.FileType fileType )
    {
        if ( fileType != null ) {
            switch( fileType )
            {
                case IS_PDF:    return( new PageFooterPdf() );
               // case IS_HTML:   return( new OutfileHtml() );

                default:     return( null );
            }
        }
        else {
            return( null );
        }
    }
}
