/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-08 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

/**
 * Abstract class that places the footer on the bottom of each page.
 * Each output file type should implement it, overriding the print() method.
 * 
 * @author alb
 */
public abstract class PageFooter
{
    private PlatyFont footerFont;
    private Value<Integer> pagesToSkip;

    /**
     * Set the font, font size, and the number of pages to skip before
     * the footer is first printed.
     */
    public PageFooter()
    {
        footerFont = new PlatyFont( true, PlatyConst.DEFAULT_FOOTER_TYPEFACE,
                                    PlatyConst.DEFAULT_FOOTER_FONT_SIZE_PTS );
        pagesToSkip = new Value<Integer>( PlatyConst.DEFAULT_FOOTER_PAGES_TO_SKIP );
    }

    /**
     * Set the number of pages to skip before the footer is first printed.
     * Typically, this is set to 1, so that the first page of a document
     * has no page number. In a single-page doc, this is standard. In a
     * multipage doc, the first page is often a cover sheet, so a page number
     * is not needed or wanted.
     * @param pagesPriorToFooter  pages to skip
     */
    public void setPagesToSkip( final int pagesPriorToFooter )
    {
        pagesToSkip.setValue( pagesPriorToFooter );
    }

    public int getPagesToSkip()
    {
        return ( Integer.valueOf( pagesToSkip.getValue() ));
    }

    /**
     * Get the line # where the pages to skip was set.
     * @return  line number
     */
    public int getPagesToSkipLine()
    {
        return( pagesToSkip.getLineNumber() );
    }

    public void setPlatyFont( PlatyFont f )
    {
        footerFont = f;
    }

    public PlatyFont getPlatyFont()
    {
        return footerFont;
    }

    public int print()
    {
        return Status.OK;
    }
}
