/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

 /**
 * Processes the indent of the first line of a paragraph
 * @author alb
 */
public class ParaIndent extends CommandValue {
    public ParaIndent( String s, String t ) { super( s, t ); }
    public ParaIndent( float f ) { super( f ); }

    @Override
    public String stateError( String s )
    {
        final Literals lits = Literals.getInstance();

        if ( s != null ) {
            final StringBuffer errMsg = new StringBuffer( 20 );

            errMsg.append( lits.getLit( "ERR_INVALID_PARA_INDENT" ))
                  .append( s )
                  .append( " ")
                  .append( lits.getLit( "AT_LINE"))
                  .append( ": " )
                  .append( getLineNumber() );

            GDD.getInstance().getLogger().warning( errMsg.toString() );
            return( errMsg.toString() );
        }
        else {
            return( null );
        } 
    }

    @Override
    public String dump()
    {
        final Literals lits = Literals.getInstance();
        final StringBuffer sb = new StringBuffer();

        sb.append( lits.getLit( "PARA_INDENT_1ST_LINE" ))
          .append( " (" )
          .append( lits.getLit( "LINE" ))
          .append( " " )
          .append( getLineNumber() )
          .append( ") " )
          .append( getAmount() )
          .append(  " " )
          .append( lits.getLit( "POINTS" ))
          .append( " = "  )
          .append( DumpValue.pointsToInches( getAmount() ));
        return( sb.toString() );
    }
}

