/*
 *(c) Copyright 2007 Pacific Data Works LLC. All Rights Reserved.
 * Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 *
 **/

package platypus;


/**
 * Handles the command specifying the amount of space (generally, the number of lines) to skip
 * before the beginning of a new paragraph.
 *
 * @author alb
 */
public class ParaSkip extends CommandValue {
    public ParaSkip( String s, String t ) { super( s, t ); }
    public ParaSkip( float f ) { super( f ); }

    @Override
    public String stateError( final String s )
    {
        final Literals lits = Literals.getInstance();

        if ( s != null ) {
            final StringBuffer errMsg = new StringBuffer( 20 );

            errMsg.append( lits.getLit( "ERR_INVALID_PARA_SKIP" ))
                  .append( " [" )
                  .append( s )
                  .append( " ")
                  .append( lits.getLit( "AT_LINE"))
                  .append( ": " )
                  .append( getLineNumber() );

            GDD.getInstance().getLogger().warning( errMsg.toString() );
            return( errMsg.toString() );
        }
        else {
            return( null );
        }            
    }

     /**
     * Creates a string containing the line # and the value for the height of the strikethrough
     * line when last set
     * @return formatted string suitable for use in dump()
     */
    @Override
    public String dump()
    {
        final Literals lits = Literals.getInstance();

        final StringBuffer sb = new StringBuffer();
        sb.append( lits.getLit( "PARA_SKIP"))
          .append( " (" )
          .append(  lits.getLit( "LINE" ))
          .append( " " )
          .append( getLineNumber() )
          .append( ") " )
          .append(  DumpValue.pointsFormatted( getAmount() ))
          .append( " " )
          .append( lits.getLit( "POINTS" ))
          .append( " = " )
          .append( DumpValue.pointsToInches( getAmount() ));
        return( sb.toString() );
    }
}
