/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

/**
 *  Status and error codes used in Platypus
 */
public class Status
{
    /*
     * utility value
     */

    public static final boolean ON              =       true;
    public static final boolean OFF             =       false;

    
    public static final int OK                  =         0;    // no error
    public static final int NO_ERROR            =         0;
    
    public static final int COMPLETE            =       Integer.MAX_VALUE;

    /*
     *  status items
     */

    public static final int AT_EOF              =        -1;

    public static final int PAGE_ADDED          =       301;
    public static final int PAGE_NOT_ADDED      =       302;

    /*
     * error codes. To test for any/all possible errors in code, test for <= Status.ERR
     */
    
    public static final int ERR                 =       -10;    // the generic non-fatal error

    public static final int IO_ERR              =       -11;
    public static final int ILLEGAL_OP          =       -12;
    public static final int OP_NOT_PERMITTED    =       -13;
    public static final int UNSUPPORTED_COMMAND =       -14;

    public static final int FILE_NOT_FOUND_ERR  =       -50;
    public static final int FILE_NOT_READABLE_ERR =     -51;

    public static final int INVALID_DATA        =      -100;    // the generic invalid data item
    public static final int INVALID_PARAM       =      -101;
    public static final int INVALID_PARAM_NULL  =      -102;
    public static final int MISSING_PARAM       =      -103;
    public static final int ERR_UNSUPPORTED_FORMAT =   -104;
    public static final int INVALID_UNIT        =      -105;
    public static final int INVALID_GDD         =      -106;
    public static final int INVALID_OUTFILE     =      -107;
    public static final int INVALID_COMMAND     =      -108;

    public static final int INVALID_TOKEN       =      -110;
    public static final int INVALID_TOKEN_NULL  =      -111;
    public static final int MISSING_TOKEN       =      -112;
    
    public static final int UNCLOSED_COMMENT_BLK=      -151;
    public static final int UNCLOSED_COMMAND    =      -152;

    public static final int DOCUMENT_CLOSED_ERR =      -201;

    public static final int ERR_NUMBER_OF_COLUMNS =    -301;    // errors in specific commands
    public static final int ERR_MARGIN_SPECIFIED  =    -302;
    public static final int ERR_MARGIN_SIZE     =      -303;
    public static final int ERR_PAGE_HEIGHT     =      -304;
    public static final int ERR_PAGE_WIDTH      =      -305;
    public static final int ERR_PARA_SKIP       =      -306;
    public static final int ERR_FONT_SIZE       =      -307;
    public static final int ERR_ALIGNMENT       =      -308;
    public static final int ERR_MACRO_NOT_FOUND =      -309;

    public static final int UNREACHABLE_ERR     =      -901;    // reached code that s/be unreachable

    public static final int FATAL_ERR           =      -999;    // non-specific fatal error
}
