/*
 *(c) Copyright 2007 Pacific Data Works LLC. All Rights Reserved.
 * Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 **/

package platypus;

/**
 * Manage strikethrough characteristics of text
 *
 * @author alb
 */
public class Strikethru extends CommandValue //CommandValue needed in HTML only. Eliminate?
{
    private Value<Boolean> strikethruActive;
    private int lineNumber;

    /** height in points of where the strikethruline should go (used in PDF) */
    private float height;

    public Strikethru()
    {
        strikethruActive = new Value<Boolean>( false );
        lineNumber = GID.getInstance().getCurrLine().getLineNumber();
        height = PlatyConst.DEFAULT_FONT_SIZE_PTS /
                 PlatyConst.FONT_SIZE_TO_STRIKETHRU_RATIO;
    }

    /**
     * If new value is different from current setting, then
     * reset the current setting to the new value.
     * @param onOff the new setting
     */
    public void setActive( final boolean onOff )
    {
        if ( isActive() != onOff ) {
            strikethruActive.setValue( onOff );
        }

        lineNumber = GID.getInstance().getCurrLine().getLineNumber();
    }

    /**
     * is strikethrough turned on currently?
     * @return the current setting
     */
    public boolean isActive()
    {
        return( Boolean.valueOf( strikethruActive.getValue() ));
    }

    public float getHeight()
    {
        return height;
    }

    public void setHeight( final float height )
    {
        this.height = height;
    }

    /**
     * Creates a string containing the line # and the value of strikethrough
     * when last set
     * @return formatted string suitable for use in dump()
     */

    public String dump()
    {
        final Literals lits = Literals.getInstance();

        final StringBuffer sb = new StringBuffer();
        sb.append( lits.getLit( "STRIKETHROUGH"))
          .append( " (" )
          .append(  lits.getLit( "LINE" ))
          .append( " " )
          .append( lineNumber )
          .append( ") " );

        if ( isActive() ) {
            sb.append( lits.getLit( "ON"));
        }
        else {
            sb.append( lits.getLit( "OFF" ));
        }

        return( sb.toString() );
    }
}
