/*-
 *  Platypus is (c) Copyright 2006 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

/**
 *  Enums representing the various input and command tokens, plus special characters
 *  and symbols. Note: error status codes are in Status.java
 *
 *  @author alb
 */
public enum TokTyp
{
    // tokens identifiers generated by the initial parser. There are only four of these.

    LINE_NUMBER,
    TEXT,
    COMMAND,
    EOF,

    // tokens that identify Platypus commands/actions

    ALIGNMENT,
    BOLD_OFF,
    BOLD_ON,
    BOTTOM_MARGIN,
    COLUMNS,
    DEFINE_MACRO,
    DUMP,
    FONT_FACE,
    FONT_SIZE,
    ITALICS_OFF,
    ITALICS_ON,
    LEADING,
    LEFT_MARGIN,
    MARGIN_MIRROR,
    NEW_PAGE,
    NEW_PARAGRAPH,
    NO_INDENT,
    PAGE_HEIGHT,
    PAGE_NUMBER,
    PAGE_NUMBER_FORMAT,
    PAGE_SIZE,
    PAGE_WIDTH,
    PARA_INDENT,
    PARA_INDENT_1,
    PARA_SKIP,
    PRINT_MACRO,
    RIGHT_MARGIN,
    STRIKETHRU_OFF,
    STRIKETHRU_ON,
    TOP_MARGIN,
    UNDERLINE_OFF,
    UNDERLINE_ON,

    // special tokens used for testing and indicating errors

    DO_NOTHING,
    INVALID_COMMAND,
    UNCLOSED_COMMAND,    // results from command with improper syntax
    UNUSED_COMMAND,

    // special characters (note: those with an * after the comment are not yet implemented)

    A_ACUTE,              // 
    A_CIRCUMFLEX,         // 
    A_GRAVE,              // 
    A_UMLAUT,             // 
    A_MACRON,             //   *
    A_CARON,              //   *
    A_BREVE,              //   *
    A_TILDE,              //  *
    A_CIRCLE,             //
    A_CAP_ACUTE,          // 
    A_CAP_CIRCUMFLEX ,    // 
    A_CAP_GRAVE,          // 
    A_CAP_UMLAUT,         // 
    A_CAP_MACRON,         //   *
    A_CAP_CARON,          //   *
    A_CAP_BREVE,          //   *
    A_CAP_TILDE,          //  *
    A_CAP_CIRCLE,         //  *

    C_CEDILLA,            // 
    C_CAP_CEDILLA,        // 
    COPYRIGHT,            // 

    E_ACUTE,              // 
    E_CIRCUMFLEX,         // 
    E_GRAVE,              // 
    E_UMLAUT,             // 
    E_MACRON,             //   *
    E_CARON,              //   *
    E_BREVE,              //   *
    E_TILDE,              //   *
    E_CIRCLE,             //
    E_CAP_ACUTE,          // 
    E_CAP_CIRCUMFLEX,     // 
    E_CAP_GRAVE,          // 
    E_CAP_UMLAUT,         // 
    E_CAP_MACRON,         //   *
    E_CAP_CARON,          //   *
    E_CAP_BREVE,          //   *
    E_CAP_TILDE,          //   *
    E_CAP_CIRCLE,         //   *    
    EM_DASH,              // --
    EN_DASH,              // -

    I_ACUTE,              // 
    I_CIRCUMFLEX,         // 
    I_GRAVE,              // 
    I_UMLAUT,             // 
    I_MACRON,             //   *
    I_CARON,              //   *
    I_BREVE,              //   *
    I_TILDE,              //   *
    I_CIRCLE,             //
    I_CAP_ACUTE,          // 
    I_CAP_CIRCUMFLEX,     // 
    I_CAP_GRAVE,          // 
    I_CAP_UMLAUT,         // 
    I_CAP_MACRON,         //   *
    I_CAP_CARON,          //   *
    I_CAP_BREVE,          //   *
    I_CAP_TILDE,          //   *
    I_CAP_CIRCLE,         //   *
    INVERTED_EXCLAM,      // 
    INVERTED_QUESTION,    // 

    N_TILDE,              // 
    N_CAP_TILDE,          // 

    O_ACUTE,              // 
    O_CIRCUMFLEX,         // 
    O_GRAVE,              // 
    O_UMLAUT,             // 
    O_MACRON,             //   *
    O_CARON,              //   *
    O_BREVE,              //   *
    O_TILDE,              //   *
    O_CIRCLE,             //   *
    O_CAP_ACUTE,          // 
    O_CAP_CIRCUMFLEX,     // 
    O_CAP_GRAVE,          // 
    O_CAP_UMLAUT,         // 
    O_CAP_MACRON,         //   *
    O_CAP_CARON,          //   *
    O_CAP_BREVE,          //   *
    O_CAP_TILDE,          //   *
    O_CAP_CIRCLE,         //   *

    QUOTE_DOUBLE_LEFT,
    QUOTE_DOUBLE_RIGHT,
    QUOTE_SINGLE_LEFT,
    QUOTE_SINGLE_RIGHT,

    REGISTERED,           // 

    S_SHARP,              // 

    U_ACUTE,              // 
    U_CIRCUMFLEX,         // 
    U_GRAVE,              // 
    U_UMLAUT,             // 
    U_MACRON,             //   *
    U_CARON,              //   *
    U_BREVE,              //   *
    U_TILDE,              //   *
    U_CIRCLE,             //
    U_CAP_ACUTE,          // 
    U_CAP_CIRCUMFLEX,     // 
    U_CAP_GRAVE,          // 
    U_CAP_UMLAUT,         // 
    U_CAP_MACRON,         //   *
    U_CAP_CARON,          //   *
    U_CAP_BREVE,          //   *
    U_CAP_TILDE,          //   *
    U_CAP_CIRCLE          //   *
}
