/**
 *  Platypus is (c) Copyright 2007 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

/**
 * Process the token from the input line of text.
 * 
 * Note: this class has no setters. A Token is only created and read. Its contents
 * are never changed, so there is no need for setters.
 *
 * @author alb
 */
public class Token
{
    private final TokTyp type;
    private final String content;

    /**
     * create a token consisting of the token type and its contents
     * @param tokenType (for possible value, see TokTyp.java)
     * @param tokenContent  string containing the lexeme
     */
    public Token( final TokTyp tokenType, final String tokenContent )
    {
        type = tokenType;
        content = tokenContent;
    }

    /**
     * return the type of token
     * @return type of token (for possible values, see TokTyp.java)
     */
    public TokTyp getType()
    {
        return( type );
    }

    /**
     * return the content portion of the token (a String)
     * @return  content
     */
    public String getContent()
    {
        return( content );
    }
}
