/*--
 *  (c) Copyright 2006-7 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus;

/**
 * Handle underlining of text. Note: currently Platypus does not allow specifying location of
 * underline, nor changing the thickness or color of the line. This will change in the future.
 * @author alb
 */
public class Underline {
    /** the location of underline relative to the baseline. Is always <= 0, i.e., below baseline */
    private float location;

    /** is underlining in effect currently? */
    private boolean inEffect;

    /** line number where the value of Underline was last changed */
    private int lineNumber;

    public Underline()
    {
        inEffect = false;
        location = PlatyConst.DEFAULT_UNDERLINE_LOCATION;
        lineNumber = GID.getInstance().getCurrLine().getLineNumber();
    }

    public boolean isInEffect()
    {
        return( inEffect );
    }

    public void setEnabled( final boolean yesOrNo )
    {
        inEffect = yesOrNo;
        lineNumber = GID.getInstance().getCurrLine().getLineNumber();
    }

    public float getLocation()
    {
        return( location );
    }

    public int getLineNumber()
    {
        return( lineNumber );
    }

    public String dump()
    {
        final Literals lits = Literals.getInstance();

        final StringBuffer sb = new StringBuffer();
        sb.append( lits.getLit( "UNDERLINE" ))
          .append( " (" )
          .append(  lits.getLit( "LINE" ))
          .append( " " )
          .append( lineNumber )
          .append( ") " )
          .append( isInEffect() ? lits.getLit( "ON" ) : lits.getLit( "OFF" ));
        return( sb.toString() );
    }
}
