/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.commands;

import platypus.*;

/**
 * Executes command for: defining a macro. This command should not be overwritten by plug-ins,
 * as it is a command that is input/output file independent and part of core Platypus processing.
 *
 * @author alb
 */
public class CommandDefineMacro extends Command
{
    public CommandDefineMacro()
    {
        setAbbrev( "[def:" );
        setName( lits.getLit( "DEFINE_MACRO" ));
        setType( TokTyp.DEFINE_MACRO );
    }

    /**
     * Parse the definition and add the definition to the UserStrings table.
     * The entire command string should use this format: [def:Name{value}]
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK if all went well; otherwise, the appropriate error code
     */
    public int process( final String actualCommand )
    {
        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        // this check is needed because this command is loaded before GDD is initialized.
        if ( gdd == null ) {
            gdd = GDD.getInstance();
        }

        if ( actualCommand.length() < ( getAbbrev().length() + 1 ) ||
            ! actualCommand.startsWith( getAbbrev() )) {
            return( Status.INVALID_COMMAND );
        }

        // is the definition properly formed? Should be: [def:Name{value}]
        if ( actualCommand.indexOf( ':' ) != 4 || actualCommand.indexOf( '{' ) == -1 ||
             actualCommand.charAt( actualCommand.length() - 1 ) != ']' ) {
            return( Status.INVALID_PARAM );
        }

        final StringBuffer name = new StringBuffer( actualCommand.length() );
        final StringBuffer value = new StringBuffer( actualCommand.length() );
        int i;

        for ( i = getAbbrev().length(); i < actualCommand.length(); i++ ) {
            if( actualCommand.charAt(i) != '{' ) {
                name.append( actualCommand.charAt(i) );
            }
            else {
                break;
            }
        }

        // TODO: should search for delimiters with multiple {. So: {{{ and }}}, for example
        for ( ++i; i < actualCommand.length(); i++ )
            if ( actualCommand.charAt(i) != '}' ) {
                value.append( actualCommand.charAt( i ));
            }
            else {
                break;
            }

        String nameStr = name.toString();
        String valueStr = value.toString();
        Platypus.macros.add( nameStr, valueStr );


        return( Status.OK );
    }
}

//from CommandProcessor.java
//
//
//    /**
//     * Defines a string to place in the macro dictionary
//     * @param tok string containing the command with the macro name and the substitute text
//     */
//    public void doDefineMacro( final String tok )
//    {
//        if ( tok == null ) {
//            return;
//        }
//
//        // is the definition properly formed? Should be: [def:Name{value}]
//        if ( tok.indexOf( ':' ) != 4 || tok.indexOf( '{' ) == -1 ||
//             tok.charAt( tok.length() - 1 ) != ']' ) {
//            return;
//        }
//
//        final StringBuffer name = new StringBuffer( tok.length() );
//        final StringBuffer value = new StringBuffer( tok.length() );
//        int i;
//
//        for ( i = 5; ; i++ ) {
//            if( tok.charAt(i) != '{' ) {
//                name.append( tok.charAt(i) );
//            }
//            else {
//                break;
//            }
//        }
//
//        // TODO: should search for delimiters with multiple {. So: {{{ and }}}, for example
//        for ( ++i ;; i++ )
//            if ( tok.charAt(i) != '}' ) {
//                value.append( tok.charAt( i ));
//            }
//            else {
//                break;
//            }
//
//        String nameStr = name.toString();
//        String valueStr = value.toString();
//        Platypus.macros.add( nameStr, valueStr );
//    }