/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.commands;

import platypus.*;


/**
 * Executes command for: printing a macro string. This command should not be overwritten by plug-ins
 * as it is a command that is input/output file independent and part of core Platypus processing.
 *
 * @author alb
 */
public class CommandPrintMacro extends Command
{
    public CommandPrintMacro()
    {
        setAbbrev( "[*" );
        setName( lits.getLit( "PRINT_MACRO" ));
        setType( TokTyp.PRINT_MACRO );
    }

    /**
     * Parse the definition and add the definition to the UserStrings table.
     * The entire command string should use this format: [def:Name{value}]
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK if all went well; otherwise, the appropriate error code
     */
    public int process( final String actualCommand )
    {
        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        // this check is needed because this command is loaded before GDD is initialized.
        if ( gdd == null ) {
            gdd = GDD.getInstance();
        }
        
        if ( actualCommand.length() < ( getAbbrev().length() + 1 ) ||
            ! actualCommand.startsWith( getAbbrev() )) {
            return( Status.INVALID_COMMAND );
        }

        final String actualKey =
                actualCommand.substring( getAbbrev().length(), actualCommand.length()-1 );
        String text = Platypus.macros.get( actualKey );
        if ( text != null ) { // TODO: verify that an error returns null
            gdd.getOutfile().emitText( text );
        }
        else {
            gdd.getLogger().severe( lits.getLit( "ERR_SUBSTITUTE_STRING_NOT_FOUND" ) +
                                    " " + actualCommand );
            return( Status.ERR_MACRO_NOT_FOUND );
        }

        return( Status.OK );
    }
}

// from CommandProcessor.java:
//
//    /**
//     * Look up the macro and in the table and output the substitute string into text
//     * @param  rawKey macro in []'s whose text must  be looked up and printed
//     */
//    public void doPrintMacro( final String rawKey )
//    {
//        final String commandPrefix = "[*";
//        final String actualKey = rawKey.substring( commandPrefix.length(), rawKey.length()-1 );
//        String text = Platypus.macros.get( actualKey );
//        if ( text != null ) { // TODO: verify that an error returns null
//            gdd.getOutfile().emitText( text );
//        }
//        else {
//            gdd.getLogger().severe( lits.getLit( "ERR_SUBSTITUTE_STRING_NOT_FOUND" ) +
//                                    " " + rawKey );
//        }
//    }