/***
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.html;

import platypus.*;
import platypus.html.commands.*;

/**
 * Converts command strings from Platypus documents into actions.
 * It consists of putting all the classes that perform these actions
 * into the command table, where they will be loaded and run.
 *
 * @author alb
 */
public class CommandProcess extends CommandProcessor
{
    public CommandProcess()
    {
        gdd = GDD.getInstance();
        gid = GID.getInstance();
        lits = Literals.getInstance();

        initializeCommandTable();
    }

    /**
     * Load the individual commands supported by HTML into the command table.
     * These commands overwrite the default commands in the table, as it was
     * initialized in Platypus. (Default: emit warning that the command is not
     * supported.) Consequently, any commands not loaded here into the table,
     * will default to the unsupported error message.
     */
    public void initializeCommandTable()
    {
        CommandTable ct = gdd.getCommandTable();
        
        ct.load( new CommandFontBoldOff() );
        ct.load( new CommandFontBoldOn() );
        ct.load( new CommandFontItalicsOff() );        
        ct.load( new CommandFontItalicsOn() );
        ct.load( new CommandNewParagraph() );
        ct.load( new CommandStrikethruOff() );
        ct.load( new CommandStrikethruOn() );
        ct.load( new CommandUnderlineOn() );
        ct.load( new CommandUnderlineOff() );
    }

}
