/***
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.html.commands;

import platypus.Command;
import platypus.TokTyp;
import platypus.Status;
import platypus.PlatyFont;

/**
 * Executes command for: turning bold on
 *
 * @author alb
 */
public class CommandFontBoldOn extends Command {
    public CommandFontBoldOn()
    {
        setAbbrev( "[+b]" );
        setName( lits.getLit( "BOLD_ON" ));
        setType( TokTyp.BOLD_ON );
    }

    /**
     * Only execute this if the present bold state is off. Update GDD's current font,
     * and then emit the HTML
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        final PlatyFont currF = gdd.getCurrFont();
        if ( ! currF.isBold() ) {
            currF.setBold( true );
            currF.setLineNumber( gid.getCurrLine().getLineNumber() );
            currF.setFont( currF.setupFont() );
            gdd.setCurrFont( currF );

            gdd.getOutfile().emitText( "<b>" );
        }
        return( Status.OK );
    }
}
