/***
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.html.commands;

import platypus.Command;
import platypus.TokTyp;
import platypus.Status;
import platypus.PlatyFont;

/**
 * Executes command for: turning italics off
 *
 * @author alb
 */
public class CommandFontItalicsOff extends Command
{
    public CommandFontItalicsOff()
    {
        setAbbrev( "[-i]" );
        setName( lits.getLit( "ITALICS_OFF" ));
        setType( TokTyp.ITALICS_OFF );
    }

    /**
     * Only execute this if the present italics state is on. Update GDD's current font,
     * and then emit the HTML
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getOutfile() == null ) {
            return( Status.INVALID_GDD );
        }

        final PlatyFont currF = gdd.getCurrFont();
        if ( currF.isItalic() ) {
            currF.setItalic( false );
            currF.setLineNumber( gid.getCurrLine().getLineNumber() );
            currF.setFont( currF.setupFont() );

            gdd.getOutfile().emitRawText( "</em>" );
        }

        return( Status.OK );
    }
}
