/*-
 *  Platypus (Page Layout and Typesetting System) http://platypus.pz.org
 *
 *  (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 **/

package platypus.html.commands;

import platypus.*;
import static platypus.Status.*;    // note the import static for status

/**
 * Executes command for: creating a new paragraph
 *
 * @author alb
 */
public class CommandNewParagraph extends Command
{
    public CommandNewParagraph()
    {
        setAbbrev( "[]" );
        setName( lits.getLit( "NEW_PARAGRAPH" ));
        setType( TokTyp.NEW_PARAGRAPH );
    }

    /**
     * new paragraph is generally performed in Outfile. This command simply triggers it.
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( String actualCommand )
    {
        if (( gdd == null ) || ( gdd != null && gdd.getOutfile() == null )) {
            return( INVALID_GDD );
        }

        gdd.getOutfile().doNewParagraph();
        return( OK );
    }
}
