/***
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.html.commands;

import platypus.Command;
import platypus.TokTyp;
import platypus.Status;
import platypus.Strikethru;

/**
 * Executes command for: turning strikethru off
 *
 * @author alb
 */
public class CommandStrikethruOff extends Command
{
    public CommandStrikethruOff()
    {
        setAbbrev( "[-st]" );
        setName( lits.getLit( "STRIKETHRU_OFF" ));
        setType( TokTyp.STRIKETHRU_OFF );
    }

    /**
     * Only execute this if the present strikethru state is on. Update GDD's underline
     * status, and then emit the HTML
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        Strikethru gddStrikethru = gdd.getStrikethru();

        if ( gddStrikethru.isActive()  ) {
            gddStrikethru.setActive( false );
            gdd.getOutfile().emitRawText( "</s>" );
        }
        return( Status.OK );
    }
}
