/***
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.html.commands;

import platypus.Command;
import platypus.TokTyp;

import platypus.Status;

/**
 * Executes command for: turning underline off
 *
 * @author alb
 */
public class CommandUnderlineOff extends Command {
    public CommandUnderlineOff()
    {
        setAbbrev( "[-u]" );
        setName( lits.getLit( "UNDERLINE_OFF" ));
        setType( TokTyp.UNDERLINE_OFF );
    }

    /**
     * Only execute this if the present underline state is on. Update GDD's underline
     * status, and then emit the HTML
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getOutfile() == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getUnderline().isInEffect()  ) {
            gdd.getUnderline().setEnabled( false );
            gdd.getOutfile().emitRawText( "</u>" );
        }
        return( Status.OK );
    }
}
