/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-08 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf;

import com.lowagie.text.pdf.*;
import com.lowagie.text.Document;
import platypus.*;

/**
 * Places the page number as a footer on the bottom of each page (to the right)
 * Once it's working, it will be converted into a command.
 *
 * @author alb
 */
public class OnPageEnd extends PdfPageEventHelper
{
    /**
     * Set the font, font size, and the number of pages to skip before
     * the footer is first printed.
     */
    public OnPageEnd() {}

    /**
     * Print the footer consisting of em-dash + page number + em-dash if we have skipped a
     * sufficient number of pages without a footer.
     * @param writer  used for writing the footer
     * @param document the document in which the footer will be written
     */
    @Override
    public void onEndPage( final PdfWriter writer, final Document document )
    {
        GDD.getInstance().getFooter().print();
        postFooterProcessing();
    }

    /**
     * processing to be done after Footer is written out.
     */
    public void postFooterProcessing()
    {
        // set columns all columns to start at top of next page
        GDD.getInstance().getColumns().startColumnsAtTop();
    }
}