/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-08 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf;

import com.lowagie.text.Document;
import com.lowagie.text.pdf.*;
import platypus.*;

/**
 * Abstract class that laces the page number as a footer on the bottom of each page.
 * Each output type should implement it, overriding the print() method.
 *
 * @author alb
 */
public class PageFooterPdf extends PageFooter
{
    /** fields from iText */
    private Document iTDocument;
    private PdfWriter iTWriter;

    public void setWriter( PdfWriter writer )
    {
        iTWriter = writer;
    }

    public void setDocument( Document document )
    {
        iTDocument = document;
    }

    /**
     * Generate and print the footer, if we are at a page where the footer should be printed.
     * Much of this is copied directly from iText example
     * @return Status.OK if all went well.
     */
    @Override
    public int print()
    {
        if ( GDD.getInstance().getPageCounter().get() > getPagesToSkip() ) {
            final float BASELINE_LOCATION = 20.0f;

            PdfContentByte cb = iTWriter.getDirectContent();
            cb.saveState();

            final String footerText = createFooterText();

            final float footerTextSize = getPlatyFont().getFont().getBaseFont().getWidthPoint(
                    footerText, 10 );

            final float footerBaseline = iTDocument.bottom() - BASELINE_LOCATION;
            final BaseFont baseFont = getPlatyFont().getFont().getBaseFont();
            final float footerFontSize = getPlatyFont().getFont().getCalculatedSize();

            // the actual process of writing at an absolute location.
            cb.beginText();
            cb.setFontAndSize( baseFont, footerFontSize );
            //   cb.setTextMatrix( document.right() - footerTextSize - 10.0f , footerBaseline );
            cb.setTextMatrix( iTDocument.right() - footerTextSize, footerBaseline );
            cb.showText( footerText );
            cb.endText();
        }

        return Status.OK;
    }

    /**
     * Create the text we'll be writing out to the footer.
     * @return  string containing the generated footer text
     */
    private String createFooterText()
    {
        int i = GDD.getInstance().getPageNumber().get();

        PageNumberFormat pnf = new PageNumberFormat();
        String formattedPageNumber = pnf.formatPageNumber(
                i, GDD.getInstance().getPageNumberFormat().getFormat() );
    //    final String footerText = " " + formattedPageNumber + " ";
        final String footerText = "\u2014 " + formattedPageNumber + " \u2014";
        return( footerText );
    }
}