/*-
 *  (c) Copyright 2006-7 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 *
 *  For more information about platter, go to http://platypus.pz.org
 */

package platypus.pdf.commands;

import platypus.Command;
import platypus.TokTyp;
import platypus.Status;
import platypus.Alignment;

/**
 * Executes command for: set text alignment to left, center, right, or justified
 *
 * @author alb
 */
public class CommandAlignment extends Command
{
    public CommandAlignment()
    {
        setAbbrev( "[align:" );
        setName( lits.getLit( "ALIGNMENT" ));
        setType( TokTyp.ALIGNMENT );
    }

    /**
     * Only execute this command if the new alignment value differs
     * from the present alignment.
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( final String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getAlignment() == null ) {
            return( Status.INVALID_GDD );
        }

        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( actualCommand.equals( "[align:center]" )) {
            if ( gdd.getAlignment().getPresent() != Alignment.type.CENTER ) {
                gdd.getAlignment().setPresent( Alignment.type.CENTER );
            }
        }
        else
        if ( actualCommand.equals( "[align:justified]" ) ||  // can be specified in short form
             actualCommand.equals( "[align:just]" )) {
            if ( gdd.getAlignment().getPresent() != Alignment.type.JUSTIFIED ) {
                gdd.getAlignment().setPresent( Alignment.type.JUSTIFIED );
            }
        }
        else
        if ( actualCommand.equals( "[align:left]" )) {
            if ( gdd.getAlignment().getPresent() != Alignment.type.LEFT ) {
                gdd.getAlignment().setPresent( Alignment.type.LEFT );
            }
        }
        else
        if ( actualCommand.equals( "[align:right]" )) {
            if ( gdd.getAlignment().getPresent() != Alignment.type.RIGHT ) {
                gdd.getAlignment().setPresent( Alignment.type.RIGHT );
            }
        }
        else {
            gdd.getLogger().warning(
                    lits.getLit( "ERR_INVALID_TEXT_ALIGNMENT" ) + " at " +
                    lits.getLit( "LINE" ) + ": " + gid.getCurrLine().getLineNumber() );
            gdd.getAlignment().setPresent( Alignment.type.LEFT );
            return( Status.ERR_ALIGNMENT );
        }

        return( Status.OK );
    }
}
