/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.*;


/**
 * Executes command for: dumping groups of variables. (Primarily intended for the
 * user in debugging.)
 *
 * @author alb
 */
public class CommandDump extends Command
{
    public CommandDump()
    {
        setAbbrev( "[dump:" );
        setName( lits.getLit( "DUMP" ));
        setType( TokTyp.DUMP );
    }

    /**
     * Determine which variables to dump and then output them.
     *
     * @param actualCommand the actualCommand specifying what to dump
     * @return Status.OK, if all went well. Otherwise the appropriate error code.
     */
    @Override
    public int process( final String actualCommand )
    {

        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( actualCommand.equals( "[dump:all]" )) {
            gdd.dumpGDD();      //TODO: eventually move this out of GDD.
        }
        else
        if ( actualCommand.equals( "[dump:page]")) {
            doDumpPage();
        }
        else
        if ( actualCommand.equals( "[dump:userStrings]")) {
            System.out.println( Platypus.macros.dumpUserStrings() );
        }
        else
        if ( actualCommand.equals( "[dump:platyStrings]" )) {
            System.out.print( Platypus.macros.dumpPlatypusStrings() );
        }
        else {
            return( Status.INVALID_COMMAND );
        }
        
        return( Status.OK );
    }

    /**
     * Dump the various elements of a page in Platypus to the console.
     */
    private void doDumpPage()
    {
        System.out.println( gdd.getPageSize().dump() );
        System.out.println( gdd.getMargin().dump( Margins.TOP ));
        System.out.println( gdd.getMargin().dump( Margins.BOTTOM ));
        System.out.println( gdd.getMargin().dump( Margins.LEFT ));
        System.out.println( gdd.getMargin().dump( Margins.RIGHT ));
    }
}

// from CommandProcessor.java
//
//
//    /**
//     * Dumps various groups of variables to console. Used for debugging.
//     * @param tok the string containing the dump command and associated parameter.
//     */
//    private void doDump( String tok )
//    {
//        if ( tok.equals( "[dump:all]" )) {
//            gdd.dumpGDD();      //TODO: eventually move this out of GDD.
//        }
//        else
//        if ( tok.equals( "[dump:page]")) {
//            doDumpPage();
//        }
//        else
//        if ( tok.equals( "[dump:userStrings]")) {
//            System.out.println( Platypus.macros.dumpUserStrings() );
//        }
//        else
//        if ( tok.equals( "[dump:platyStrings]" )) {
//            System.out.print( Platypus.macros.dumpPlatypusStrings() );
//        }
//    }
//
//    /**
//     * Dump the various elements of a page in Platypus to the console.
//     */
//    public void doDumpPage()
//    {
//        System.out.println( gdd.getPageSize().dump() );
//        System.out.println( gdd.getMargin().dump( Margins.TOP ));
//        System.out.println( gdd.getMargin().dump( Margins.BOTTOM ));
//        System.out.println( gdd.getMargin().dump( Margins.LEFT ));
//        System.out.println( gdd.getMargin().dump( Margins.RIGHT ));
//    }