/*-
 *  (c) Copyright 2006-7 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 *
 *  For more information about platter, go to http://platypus.pz.org
 */

package platypus.pdf.commands;

import platypus.Command;
import platypus.TokTyp;
import platypus.Status;
import platypus.PlatyFont;

/**
 * Executes command for: turning bold on
 *
 * @author alb
 */
public class CommandFontBoldOn extends Command
{
    public CommandFontBoldOn()
    {
        setAbbrev( "[+b]" );
        setName( lits.getLit( "BOLD_ON" ));
        setType( TokTyp.BOLD_ON );
    }

    /**
     * Only execute this if the present bold state is off. Update GDD's current font,
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized,
     */
    public int process( final String actualCommand )
    {
        // no need to test actualCommand for null or not, as it's not used

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getOutfile() == null ) {
            return( Status.INVALID_GDD );
        }

        final PlatyFont currF = gdd.getCurrFont();
        if ( ! currF.isBold() ) {
            currF.setBold( true );
            currF.setLineNumber( gid.getCurrLine().getLineNumber() );
            currF.setFont( currF.setupFont() );
        }

//> from PDF CommandPdf:
//
//        final PlatyFont currF = gdd.getCurrFont();
//        if ( currF.isBold() != boldOnOff ) {
//            currF.setBold( boldOnOff );
//            currF.setLineNumber( gid.getCurrLine().getLineNumber() );
//            currF.setFont( currF.setupFont() );

        return( Status.OK );
    }
}
