/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.Command;
import platypus.TokTyp;
import platypus.Status;
import platypus.PlatyFont;

/**
 * Executes command for: turning italics on
 *
 * @author alb
 */
public class CommandFontItalicsOn extends Command
{
    public CommandFontItalicsOn()
    {
        setAbbrev( "[+i]" );
        setName( lits.getLit( "ITALICS_ON" ));
        setType( TokTyp.ITALICS_ON );
    }

    /**
     * Only execute this if the present italics state is off. Update GDD's current font,
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getOutfile() == null ) {
            return( Status.INVALID_GDD );
        }

        final PlatyFont currF = gdd.getCurrFont();
        if ( ! currF.isItalic() ) {
            currF.setItalic( true );
            currF.setLineNumber( gid.getCurrLine().getLineNumber() );
            currF.setFont( currF.setupFont() );
        }
        return( Status.OK );
    }
}
