/*-
 *  (c) Copyright 2006-7 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 *
 *  For more information about platter, go to http://platypus.pz.org
 */

package platypus.pdf.commands;

import platypus.*;

/**
 * Executes command for: specifying leading (here, the distance between successive baselines)
 *
 * @author alb
 */
public class CommandLeading extends Command
{
    public CommandLeading()
    {
        setAbbrev( "[leading:" );
        setName( lits.getLit( "DO_LEADING" ));
        setType( TokTyp.LEADING );
    }

    /**
     * @param actualCommand the command as found in the input Platypus file
     * @return status Status.OK; various self-evident error codes for different kinds of errors.
     */
    @Override
    public int process( final String actualCommand )
    {

        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        ParsedUnit leadingPU =
                Parser.getUnitValue( actualCommand.substring( getAbbrev().length(),
                        actualCommand.length() - 1 ) );

        if ( leadingPU.getUnit() == PlatyConst.unit.ERROR ) {
            gdd.getLeading().errorMessage( actualCommand );
            return( Status.INVALID_COMMAND );
        }

        float points =
                PlatyConst.convertUnitsToPoints( leadingPU.getUnit(), leadingPU.getAmount() );

        if( points != Float.NaN ) {
            gdd.getLeading().setAmount( points );
        }
        else {
            gdd.getLeading().errorMessage( actualCommand );
            return( Status.INVALID_UNIT );
        }
        return( Status.OK );
    }
}

//---original from CommandPdf:
//
//    public void doLeading( final String leadingSpec )
//    {
//        if ( leadingSpec == null ) {
//            return;
//        }
//
//        ParsedUnit leadingPU =
//                Parser.getUnitValue( leadingSpec.substring( "[leading:".length(),
//                        leadingSpec.length() - 1 ) );
//
//        if ( leadingPU.getUnit() == PlatyConst.unit.ERROR ) {
//            gdd.getLeading().errorMessage( leadingSpec );
//            return;
//        }
//
//        float points =
//                PlatyConst.convertUnitsToPoints( leadingPU.getUnit(), leadingPU.getAmount() );
//
//        if( points != Float.NaN ) {
//            gdd.getLeading().setAmount( points );
//        }
//        else {
//            gdd.getLeading().errorMessage( leadingSpec );
//        }
//    }