/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.*;

/**
 * Executes command for: specifying top margin of page
 *
 * @author alb
 */
public class CommandMarginTop extends Command
{
    public CommandMarginTop()
    {
        setAbbrev( "[tmargin:" );
        setName( lits.getLit( "TOP_MARGIN" ));
        setType( TokTyp.TOP_MARGIN );
    }

    /**
     * Set the size (that is, height) of the top margin of the page for a PDF document
     * Though it's not used here, the default for PDF is PlatyConst.DEFAULT_MARGIN_PTS
     * 
     * @param actualCommand the command as found in the input Platypus file
     * @return status Status.OK; or another value that identified the type of error.
     */
    public int process( final String actualCommand )
    {

        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( actualCommand.length() < ( getAbbrev().length() + 1 ) ||
            ! actualCommand.startsWith( getAbbrev() )) {
            return( Status.INVALID_COMMAND );
        }

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        int returnStatus = Status.OK;

        CommandValue margin =
                    new CommandValue( actualCommand.substring( getAbbrev().length() ),
                                      actualCommand.substring( 1,7 ));

        if ( margin.getAmount() == Float.MIN_VALUE || margin.getAmount() <  0 ) {
            returnStatus = Status.INVALID_PARAM;
        }
        else {
            if ( gdd.getOutfile().hasTextBeenProcessed() ) {  // can't change margins after text
                returnStatus = Status.OP_NOT_PERMITTED;
            }
            else {  // top + bottom margin must be less than page height
                if ( margin.getAmount() + gdd.getMargin().getSize( Margins.BOTTOM ) <=
                        gdd.getPageSize().getHeight() ) {
                    gdd.getMargin().setSize( Margins.TOP, margin.getAmount() );
                }
                else {
                    returnStatus = Status.ERR_MARGIN_SIZE;
                }
            }
        }
        return( returnStatus );
    }
}
