/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.*;

/**
 * Executes command for new page
 *
 * @author alb
 */
public class CommandNewPage extends Command
{
    public CommandNewPage()
    {
        setAbbrev( "[pg]" );
        setName( lits.getLit( "NEW_PAGE" ));
        setType( TokTyp.NEW_PAGE );
    }

    /**
     * @param actualCommand not used
     * @return Status.OK, if all went well. Otherwise the appropriate error code.
     */
    @Override
    public int process( final String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getOutfile() == null ) {
            return( Status.INVALID_GDD );
        }

        final int ret = gdd.getOutfile().newPage();
        
        if ( ret == Status.DOCUMENT_CLOSED_ERR ) {
            gdd.getLogger().severe( lits.getLit( "ERR_DOC_NOT_OPEN" ) + " " +
                                lits.getLit( "COMMAND_COLON") + " " + "[pg]" +
                                lits.getLit( "LINE_NUM_SIGN") +
                                GID.getInstance().getCurrLine().getLineNumber() );
        }
        return( ret );
    }

}

//from CommandProcessor.java
//
//    /**
//     * Inserts a new page.
//     * @return Status.OK, if all went well. Otherwise the appropriate error code.
//     */
//    private int doNewPage()
//    {
//        final int ret = gdd.getOutfile().newPage();
//        if ( ret == Status.DOCUMENT_CLOSED_ERR ) {
//            gdd.getLogger().severe( lits.getLit( "ERR_DOC_NOT_OPEN" ) + " " +
//                                lits.getLit( "COMMAND_COLON") + " " + "[pg]" +
//                                lits.getLit( "LINE_NUM_SIGN") +
//                                GID.getInstance().getCurrLine().getLineNumber() );
//        }
//        return( ret );
//    }