/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.*;

/**
 * Executes command for disabling paragraph indent for the next paragraph only.
 *
 * Note: this toggle can only be turned on. When the next paragraph is output,
 * noindent is reset to false. 
 *
 * @author alb
 */
public class CommandNoindent extends Command
{
    public CommandNoindent()
    {
        setAbbrev( "[noindent]" );
        setName( lits.getLit( "NO_INDENT" ));
        setType( TokTyp.NO_INDENT );
    }

    /**
     * Only execute this if the present strikethru state is off.
     * Update GDD's noindent status.
     *
     * @param actualCommand the command as found in the input Platypus file
     * @return Status.OK or Status.INVALID_GDD if gdd has not been initialized.
     */
    public int process( String actualCommand )
    {
        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        boolean currNoindentStatus = Boolean.valueOf( gdd.getNoIndent().getValue() );
        if ( ! currNoindentStatus ) {
            gdd.getNoIndent().setValue( true );
        }

        return( Status.OK );
    }
}