/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-08 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.*;

/**
 * Executes command for: specifying the current page number.
 *
 * @author alb
 */
public class CommandPageNumber extends Command
{
    public CommandPageNumber()
    {
        setAbbrev( "[pagenumber:" );
        setName( lits.getLit( "PAGE_NUMBER" ));
        setType( TokTyp.PAGE_NUMBER );
        setRoot( null );
    }

    /**
     * Changes the page number, which is the number actually printed on the document page
     * (as opposed to the page counter). The new page number must be >= 1
     *
     * @param actualCommand the actualCommand from the input document
     * @return Status.OK, if all went well. Otherwise the appropriate error code.
     */
    @Override
    public int process( final String actualCommand )
    {
        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( actualCommand.length() < ( getAbbrev().length() + 1 ) ||
            ! actualCommand.startsWith( getAbbrev() )) {
            return( Status.INVALID_COMMAND );
        }

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        // what is the new page number?
        ParsedUnit pageNumber =
                Parser.getUnitValue( actualCommand.substring( getAbbrev().length(),
                        actualCommand.length() ));

        if ( pageNumber.getUnit() == PlatyConst.unit.ERROR || pageNumber.getAmount() < 1.0f ) {
            return( Status.INVALID_PARAM );
        }

        gdd.getPageNumber().set( (int) pageNumber.getAmount() );
        return( Status.OK );
    }
}