/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-08 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.*;
import platypus.PageNumberFormat;

/**
 * Executes command for: specifying the format of the current page number as it is printed.
 * There are three options, currently: lower-case roman numeral, upper-case roman, and standard
 * arabic. These are communicated using the format for the digit 9. So respectively the formats
 * are: ix, IX, 9
 *
 * @author alb
 */
public class CommandPageNumberFormat extends Command
{
    public CommandPageNumberFormat()
    {
        setAbbrev( "[pagenumberformat:" );
        setName( lits.getLit( "PAGE_NUMBER_FORMAT" ));
        setType( TokTyp.PAGE_NUMBER_FORMAT );
        setRoot( null );
    }

    /**
     * Changes the format of the page number as described above.
     *
     * @param actualCommand the actualCommand from the input document
     * @return Status.OK, if all went well. Otherwise the appropriate error code.
     */
    @Override
    public int process( final String actualCommand )
    {
        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( actualCommand.length() < ( getAbbrev().length() + 1 ) ||
            ! actualCommand.startsWith( getAbbrev() )) {
            return( Status.INVALID_COMMAND );
        }

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        PageNumberFormat.format newFormat;

        if ( actualCommand.equals( "[pagenumberformat:9]" )) {
            newFormat = PageNumberFormat.format.ARABIC;
        }
        else
        if ( actualCommand.equals( "[pagenumberformat:ix]" )) {
            newFormat = PageNumberFormat.format.ROMAN_LOWER;
        }
        else
        if ( actualCommand.equals( "[pagenumberformat:IX]" )) {
            newFormat = PageNumberFormat.format.ROMAN_CAPITAL;
        }
        else {
        // in the event of an error, use arabic numbers
            newFormat = PageNumberFormat.format.ARABIC;
            GDD.getInstance().getPageNumberFormat().errorMessage( actualCommand );
        }

        GDD.getInstance().getPageNumberFormat().setFormat( newFormat );
        return( Status.OK );
    }
}