/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.*;

/**
 * Executes command for specifying page size
 *
 * @author alb
 */
public class CommandPageSize extends Command
{
    public CommandPageSize()
    {
        setAbbrev( "[pagesize:" );
        setName( lits.getLit( "PAGE_SIZE" ));
        setType( TokTyp.PAGE_SIZE );
    }

    /**
     * Determine which variables to dump and then output them.
     *
     * @param actualCommand the actualCommand specifying a preset page size. All the acceptable
     * preset page sizes are defined in PageSize.java
     * @return Status.OK, if all went well. Otherwise the appropriate error code.
     */
    @Override
    public int process( final String actualCommand )
    {

        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( actualCommand.length() < getAbbrev().length() + 2 ) {
            return( Status.INVALID_PARAM );
        }

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( gdd.getOutfile().hasTextBeenProcessed() ) {
            gdd.getLogger().warning( lits.getLit( "ERR_NO_PAGESIZE_AFTER_TEXT_OUPUT" ) +
                " (" + lits.getLit( "LINE" ) + " " + gid.getCurrLine().getLineNumber() + ")" );
            return( Status.OP_NOT_PERMITTED );
        }

        // call pageSize.initialize() and pass in the parameter portion of the command string.
        try {
            gdd.getPageSize().initialize(
                actualCommand.substring( getAbbrev().length(), actualCommand.length() - 1 ));
        }
        catch ( IllegalArgumentException e ) {
             gdd.getLogger().warning( e + " " + actualCommand + " (" + lits.getLit( "LINE" ) + " " +
                    gid.getCurrLine().getLineNumber() + ")" );
            return( Status.INVALID_PARAM );
        }

        return( Status.OK );
    }
}
