/***
 *  Platypus: Page Layout and Typesetting Software (free at platypus.pz.org)
 *
 *  Platypus is (c) Copyright 2006-07 Pacific Data Works LLC. All Rights Reserved.
 *  Licensed under Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.html)
 */

package platypus.pdf.commands;

import platypus.Command;
import platypus.TokTyp;
import platypus.Status;
import platypus.ParaSkip;

/**
 * Executes command for: creating a new paragraph
 *
 * @author alb
 */
public class CommandParaSkip extends Command
{
    public CommandParaSkip()
    {
        setAbbrev( "[paraskip:" );
        setName( lits.getLit( "PARASKIP" ));
        setType( TokTyp.PARA_SKIP );
    }

    /**
     * Creates a new ParaSkip (paragraph line skip) structure, loads it with the values in the
     * command and places it in GDD, provided no error occurred. On error, an error message is
     * logged and the command is skipped.
     *
     * @param actualCommand command string as specified by the user
     * @return Status.OK; Status.INVALID_GDD if gdd has not been initialized;
     *         Status.INVALID_PARAM_NULL if null was passed in; Status.INVALID_PARAM if invalid
     *         size was specified; Status.ERR_PARA_SKIP if the amount of skip is malformed
     *         or negative.
     */
    public int process( final String actualCommand )
    {
        if ( actualCommand == null ) {
            return( Status.INVALID_PARAM_NULL );
        }

        if ( gdd == null ) {
            return( Status.INVALID_GDD );
        }

        if ( ! actualCommand.startsWith( getAbbrev() ) ||
           ( actualCommand.length() == getAbbrev().length() )) {
            return( Status.INVALID_PARAM );
        }

        // ParaSkip is a CommandValue. Creating it produces a parsing of the parameter's
        // value and units.
        final ParaSkip ps =
                new ParaSkip( actualCommand.substring( "[paraskip:".length()), "paraskip" );

        if ( ps.getAmount() < 0) {
            // if amount is MIN_VALUE, an error occurred in getting the amount
            // Likewise, if the amout to skip is negative 
            return( Status.ERR_PARA_SKIP );
        }

        gdd.getParaSkip().setAmountInPoints( ps.getAmount() );
//TODO: why is this next statement here?   (alb 2007-11-06 )
//      gdd.getOutfile().doNewParagraph();
        return( Status.OK );
    }
}
